/**
 * @class AsyncSearch
 */
import * as React from 'react';
import { CSSProperties } from 'react';
interface IAsyncSearchDropdown {
    /***
     * if true, a default styled list will appear and you will not be able to use the RenderItem prop
     */
    defaultListStyling: boolean;
    /**
     * boolean if you want to render a searchIcon
     */
    leftIcon?: boolean;
    /**
     * A boolean for if the user can press the x button and clear all the selected items
     */
    canClearAll?: boolean;
    /**
     * Placeholder text for the input object,
     * Will be replaced by the label of the items you select
     */
    placeholder?: string;
    /**
     * Will be called everytime there is a change in the selection of items, and returns the new items
     * @param items
     */
    onChange: (items: Array<any>) => void;
    /**
     * When you want the dropdown to be disabled, grey's out the box and makes it unclickable
     */
    disabled?: boolean;
    /**
     * render prop for reusibility so you can style the list of items how you want it
     * @param items that is returned by the getItems promise
     * @param i the index of each item
     * @param isActive boolean for if the item is active
     */
    renderItem?: (items: Array<any>, i: number, isActive: boolean, isSelected: boolean, img: any) => React.ReactNode;
    /**
     * if you want to change the size of the dropdown
     */
    style?: CSSProperties;
    /***
     * Message when there are no items to render
     */
    noResultMessage?: string;
    /**
     *  returns a promise with the  items that renders in the dropdown
     * @param input value from input
     */
    getItems: (input: string) => Promise<Array<any>>;
}
export declare const AsyncSearchDropdown: React.FunctionComponent<IAsyncSearchDropdown>;
export {};
